@@ -217,3 +217,24 @@ class VerifyToken:
         permission_status = {
             'permission_list': permission_list, 'is_all_data': is_all_data}
         return permission_status
+
+    def filter_verify(self, group_list, is_all_data, user_name):
+        """
+        根据用户分组权限，个人权限，用户信息。整理出符合mongo塞选语句的权限赛选条件
+        用户实际业务模块直接塞选出符合权限要求的数据
+        """
+        # 根据用户分组权限，设置相关查询过滤条件
+        auth_filter = {}
+        # 从环境变量中获取超级管理员账号信息
+        admin_user = os.environ.get('ADMIN_USER', [])
+        # 判断用户是否为超级管理员，超级管理员则跳过群组认证环节
+        if user_name in admin_user:
+            pass
+        elif group_list:
+            auth_filter.update(group_list={'$elemMatch': {'$in': group_list}})
+        else:
+            handle_abnormal(message='用户无任何群组权限，无法操作数据', status=403)
+        if not is_all_data:
+            auth_filter.update(creator=user_name)
+
+        return auth_filter
\ No newline at end of file
